@@ -9,7 +9,7 @@ class Category(ChildResource):
     CONTAINER_PATH = '/policy/accesspolicies/{uuid}'
     PATH = '/policy/accesspolicies/{container_uuid}/categories/{uuid}'
     SUPPORTED_FILTERS = []
-    SUPPORTED_PARAMS = ['below_category', 'above_category', 'section', 'insert_before', 'insert_after']
+    SUPPORTED_PARAMS = ['above_category', 'section', 'insert_before', 'insert_after']
     IGNORE_FOR_CREATE = []
     IGNORE_FOR_UPDATE = []
     MINIMUM_VERSION_REQUIRED_CREATE = '6.5.0'
@@ -23,8 +23,7 @@ class Category(ChildResource):
         data: Union[dict, list],
         container_uuid=None,
         container_name=None,
-        after_category=None,
-        before_category=None,
+        above_category=None,
         section=None,
         insert_after=None,
         insert_before=None,
